.. raw:: html
    <head>
        <meta http-equiv='refresh' content='0; URL=./index.html#build-apps'>
    </head>

# Build apps

```{toctree}
:titlesonly:
:hidden:
:maxdepth: 1

Construct individual components<components/index>
Styling components<styling/index>
Interactivity<interactivity/index>
Arranging components<layout/index>
Bind Component Parameters (Reactive API)<reactive/index>
```
